﻿using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;
using System.Windows.Shapes;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 나선 수
        /// </summary>
        private const int SPRIAL_COUNT = 20;

        /// <summary>
        /// 포인트 수
        /// </summary>
        private const int POINT_COUNT = 1000;

        /// <summary>
        /// 전체 포인트 수
        /// </summary>
        private const int TOTAL_POINT_COUNT = POINT_COUNT * SPRIAL_COUNT;

        /// <summary>
        /// 다각선
        /// </summary>
        private Polyline polyline;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            #region 포인트 컬렉션을 설정한다.

            PointCollection pointCollection = new PointCollection(TOTAL_POINT_COUNT);

            for(int i = 0; i < TOTAL_POINT_COUNT; i++)
            {
                double angle = i * 2 * Math.PI / POINT_COUNT;
                double scale = 250 * (1 - (double) i / TOTAL_POINT_COUNT);

                Point point = new Point();

                point.X = scale * Math.Cos(angle);
                point.Y = scale * Math.Sin(angle);

                pointCollection.Add(point);
            }

            #endregion
            #region 다각선을 설정한다.

            this.polyline = new Polyline();

            this.polyline.Stroke = SystemColors.WindowTextBrush;
            this.polyline.Points = pointCollection;

            this.canvas.Children.Add(this.polyline);

            #endregion
            #region 이벤트를 설정한다.

            this.canvas.SizeChanged += canvas_SizeChanged;

            #endregion
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 캔버스 크기 변경시 처리하기 - canvas_SizeChanged(sender, e)

        /// <summary>
        /// 캔버스 크기 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void canvas_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            Canvas.SetLeft(this.polyline, e.NewSize.Width  / 2);
            Canvas.SetTop (this.polyline, e.NewSize.Height / 2);
        }

        #endregion
    }
}